use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
יובל
קוג
Yuval
Kogman
nothingmuch
Infinity
Interactive
Inc
Mark
Gardner
mjgardner
Karen
Etheridge
ether
Graham
Knop
haarg
Daisuke
Maki
dmaki
Offer
Kaye
offer
brunov
vecchi
vovkasm
Ken
Crowell
oeuftete
Michael
Joyce
ubermichael
Dann
techmemo
Guillermo
Roditi
groditi
lib
MooseX
App
Cmd
Command
